Package: grec
Type: Package
Title: Gradient-Based Recognition of Spatial Patterns in Environmental
        Data
Version: 1.6.4
Date: 2026-05-13
URL: https://github.com/LuisLauM/grec
BugReports: https://github.com/LuisLauM/grec/issues
Authors@R: c(
    person(
      given = "Wencheng",
      family = "Lau-Medrano", 
      email = "luis.laum@protonmail.com", 
      role = c("aut", "cre"), 
      comment = c(ORCID = "0000-0002-7979-9710")
    )
  )
Maintainer: Wencheng Lau-Medrano <luis.laum@protonmail.com>
Description: Provides algorithms for detection of spatial patterns from oceanographic data using image processing methods based on Gradient Recognition.
License: GPL (>= 3)
Depends: R (>= 4.1.0)
Imports: utils, imagine (>= 2.1.2), raster, terra, abind, lifecycle,
        cli
LazyData: true
Encoding: UTF-8
RoxygenNote: 8.0.0
NeedsCompilation: no
Packaged: 2026-05-13 15:59:59 UTC; afipdbl
Author: Wencheng Lau-Medrano [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-7979-9710>)
Repository: CRAN
Date/Publication: 2026-05-14 14:10:16 UTC
Built: R 4.6.0; ; 2026-05-14 15:42:32 UTC; unix
