# Generated by roxygen2: do not edit by hand

S3method(getGradients,RasterLayer)
S3method(getGradients,SpatRaster)
S3method(getGradients,array)
S3method(getGradients,default)
S3method(getGradients,list)
S3method(getGradients,matrix)
export(detectFronts)
export(getGradients)
importFrom(abind,abind)
importFrom(cli,cli_abort)
importFrom(imagine,agenbagFilters)
importFrom(imagine,contextualMF)
importFrom(imagine,convolution2D)
importFrom(imagine,medianFilter)
importFrom(lifecycle,badge)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,deprecate_warn)
importFrom(lifecycle,deprecated)
importFrom(raster,nlayers)
importFrom(raster,raster)
importFrom(raster,values)
importFrom(terra,'values<-')
importFrom(terra,as.array)
importFrom(terra,crs)
importFrom(terra,ext)
importFrom(terra,nlyr)
importFrom(terra,origin)
importFrom(terra,rast)
importFrom(terra,values)
importFrom(terra,varnames)
importFrom(utils,modifyList)
importMethodsFrom(raster,"[")
importMethodsFrom(terra,"ext<-")
importMethodsFrom(terra,"origin<-")
importMethodsFrom(terra,"varnames<-")
importMethodsFrom(terra,as.matrix)
