#' @title Default color palette most using on environmental representations.
#' @description Vector with 2000 colors generated from `tim.colors` function.
#' @docType data
#' @usage colPalette
#' @format A vector of 2000 colors in RGB format.
#' @references `tim.colors` from **fields** package
"colPalette"

#' @title Sea Surface Temperature Data
#' @description SST maps downloaded from ERDDAP for running examples with
#' `grec` functions.
#' @docType data
#' @usage sst
#' @format A `list` with SST information from February to April of Aqua
#' MODIS source.
#' @references ERDDAP website: <https://coastwatch.pfeg.noaa.gov/erddap>
"sst"

#' @title Sea Surface Chlorophyll Data
#' @description Surface chlorophyll maps downloaded from ERDDAP for running
#' examples with `grec` functions.
#' @docType data
#' @usage chl
#' @format A `list` with chlorophyll information from February to April of
#' Aqua MODIS source.
#' @references ERDDAP website: <https://coastwatch.pfeg.noaa.gov/erddap>
"chl"
